@@ -2,6 +2,7 @@ import json
 import sys
 import tempfile
 
+from .constants import DEFAULT_REQUEST_THREADS_LIMIT
 from .pyxis_authentication import PyxisKrbAuth, PyxisSSLAuth
 from .pyxis_client import PyxisClient
 from .utils import setup_arg_parser
@@ -82,6 +83,12 @@ UPLOAD_SIGNATURES_ARGS[("--signatures",)] = {
     "required": True,
     "type": str,
 }
+UPLOAD_SIGNATURES_ARGS[("--request-threads",)] = {
+    "help": "Maximum number of threads to use for parallel requests",
+    "required": False,
+    "default": DEFAULT_REQUEST_THREADS_LIMIT,
+    "type": int,
+}
 
 GET_SIGNATURES_ARGS = CMD_ARGS.copy()
 GET_SIGNATURES_ARGS[("--manifest-digest",)] = {
@@ -135,6 +142,11 @@ def setup_pyxis_client(args, ccache_file):
     return PyxisClient(args.pyxis_server, auth=auth, verify=not args.pyxis_insecure)
 
 
+def set_get_operator_indices_args():
+    """Set up argparser without extra parameters, this method is used for auto doc generation."""
+    return setup_arg_parser(GET_OPERATORS_INDICES_ARGS)
+
+
 def get_operator_indices_main(sysargs=None):
     """
     Entrypoint for getting operator indices.
@@ -142,7 +154,7 @@ def get_operator_indices_main(sysargs=None):
     Returns:
         list: Index images satisfying the specified conditions.
     """
-    parser = setup_arg_parser(GET_OPERATORS_INDICES_ARGS)
+    parser = set_get_operator_indices_args()
     if sysargs:
         args = parser.parse_args(sysargs[1:])
     else:
@@ -158,6 +170,11 @@ def get_operator_indices_main(sysargs=None):
         return resp
 
 
+def set_get_repo_metadata_args():
+    """Set up argparser without extra parameters, this method is used for auto doc generation."""
+    return setup_arg_parser(GET_REPO_METADATA_ARGS)
+
+
 def get_repo_metadata_main(sysargs=None):
     """
     Entrypoint for getting repository metadata.
@@ -165,7 +182,7 @@ def get_repo_metadata_main(sysargs=None):
     Returns:
         dict: Metadata of the repository.
     """
-    parser = setup_arg_parser(GET_REPO_METADATA_ARGS)
+    parser = set_get_repo_metadata_args()
 
     if sysargs:
         args = parser.parse_args(sysargs[1:])
@@ -190,6 +207,11 @@ def get_repo_metadata_main(sysargs=None):
         return res
 
 
+def set_upload_signatures_args():
+    """Set up argparser without extra parameters, this method is used for auto doc generation."""
+    return setup_arg_parser(UPLOAD_SIGNATURES_ARGS)
+
+
 def upload_signatures_main(sysargs=None):
     """
     Entrypoint for uploading signatures from JSON or a file.
@@ -197,13 +219,13 @@ def upload_signatures_main(sysargs=None):
     Returns:
         list: List of uploaded signatures including auto-populated fields.
     """
-    parser = setup_arg_parser(UPLOAD_SIGNATURES_ARGS)
+    parser = set_upload_signatures_args()
     if sysargs:
         args = parser.parse_args(sysargs[1:])
     else:
-        args = parser.parse_args()  # pragma: no cover"
+        args = parser.parse_args()  # pragma: no cover
 
-    signatures_json = serialize_to_json(deserialize_list_from_arg(args.signatures))
+    signatures_json = deserialize_list_from_arg(args.signatures)
 
     with tempfile.NamedTemporaryFile() as tmpfile:
         pyxis_client = setup_pyxis_client(args, tmpfile.name)
@@ -239,16 +261,16 @@ def deserialize_list_from_arg(value, csv_input=False):
         return json.load(f)
 
 
-def serialize_to_json(list_value):
-    """Convert any python list to json."""
-    return json.dumps(list_value)
-
-
 def serialize_to_csv_from_list(list_value):
     """Convert a list to comma separated string."""
     return ",".join(list_value)
 
 
+def set_get_signatures_args():
+    """Set up argparser without extra parameters, this method is used for auto doc generation."""
+    return setup_arg_parser(GET_SIGNATURES_ARGS)
+
+
 def get_signatures_main(sysargs=None):
     """
     Entrypoint for getting container signature metadata.
@@ -256,7 +278,7 @@ def get_signatures_main(sysargs=None):
     Returns:
         list: container signature metadata satisfying the specified conditions.
     """
-    parser = setup_arg_parser(GET_SIGNATURES_ARGS)
+    parser = set_get_signatures_args()
     if sysargs:
         args = parser.parse_args(sysargs[1:])
     else:
@@ -284,6 +306,11 @@ def get_signatures_main(sysargs=None):
         return res
 
 
+def set_delete_signatures_args():
+    """Set up argparser without extra parameters, this method is used for auto doc generation."""
+    return setup_arg_parser(DELETE_SIGNATURES_ARGS)
+
+
 def delete_signatures_main(sysargs=None):
     """
     Entrypoint for removing existing signatures.
@@ -291,7 +318,7 @@ def delete_signatures_main(sysargs=None):
     Returns:
         list: Signatures which were deleted.
     """
-    parser = setup_arg_parser(DELETE_SIGNATURES_ARGS)
+    parser = set_delete_signatures_args()
     if sysargs:
         args = parser.parse_args(sysargs[1:])
     else:
